@@ -327,7 +327,7 @@ int main(int argc, char *argv[])
 		fprintf(fp, "\n");
 
 		fprintf(fp, "distclean: clean\n");
-		fprintf(fp, "\trm Makefile\n");
+		fprintf(fp, "\trm Makefile mbs.meta\n");
 		
 		fprintf(fp, "test:\n");
 		fprintf(fp, "\tmbs --test %s\n", mbsTests);
